@@ -1,5 +1,6 @@
 use 5.020;
 package Pg::BulkLoad;
+$Pg::BulkLoad::VERSION = '2.022'; # TRIAL
 use feature qw/signatures postderef/;
 no warnings qw/experimental uninitialized/;
 use Try::Tiny;
@@ -83,13 +84,24 @@ sub load ( $I, $file, $table, $format ) {
 
 1;
 
+__END__
+
 =pod
 
+=encoding UTF-8
+
+=head1 NAME
+
+Pg::BulkLoad - Bulk Load for Postgres with ability to skip bad records.
+
+=head1 VERSION
+
+version 2.022
+
 =head1 Pg::BulkLoad
 
 Load Comma and Tab Delimited files into Postgres, skipping bad records.
 
-
 =head1 Synopsis
 
  Shell> split -l 50000 -a 3 -d mydata.csv load
@@ -131,7 +143,7 @@ the table to load to.
 
 either text or csv
 
-=back 
+=back
 
 =head2 Reason
 
@@ -141,7 +153,7 @@ The Postgres 'COPY FROM' lacks a mechanism for skipping bad records. Sometimes w
 
 Pg::BulkLoad attempts to load your file via the COPY FROM command if it fails it removes the error for the bad line from its working copy, then attempts to load all of the records previous to the error, and then tries to load the remaining data after the failure. 
 
-If your data is clean the COPY FROM command is pretty fast, however if there are a lot of bad records, for each failure Pg::BuklLoad has to rewrite the input file. If your data has a lot of bad records small batches are recommended, for clean data performance will be better with a larger batch size. The split program will quickly split larger files, but you can split them in Perl if you prefer. To keep this program simpler I've left chunking larger files up to the user. Pg::BulkLoad does load data into memory which will create a practical maximum file.
+If your data is clean the COPY FROM command is pretty fast, however if there are a lot of bad records, for each failure Pg::BuklLoad has to rewrite the input file. If your data has a lot of bad records small batches are recommended, for clean data performance will be better with a larger batch size. To keep this program simpler I've left chunking larger files up to the user. The split program will quickly split larger files, but you can split them in Perl if you prefer. Pg::BulkLoad does hold the entire data file in memory (to improve performance on dirty files) this will create a practical maximum file size.
 
 =head2 Limitation of COPY
 
@@ -157,4 +169,17 @@ My first CPAN module was Pg::BulkCopy, because I had this problem. I found somet
 
 =head1 Testing
 
-To properly test it you'll need to export DB_TESTING to a true value in your environment before running tests. When this variable isn't set the tests mock a database for a few of the simpler tests and skip the rest.
\ No newline at end of file
+To properly test it you'll need to export DB_TESTING to a true value in your environment before running tests. When this variable isn't set the tests mock a database for a few of the simpler tests and skip the rest.
+
+=head1 AUTHOR
+
+John Karr <brainbuz@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by John Karr.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
